##
##  libarchive.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libarchive
Summary:      Archiving Format File Library
URL:          http://www.libarchive.org/
Vendor:       Tim Kientzle
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Archiver
License:      MIT-style
Version:      3.7.4
Release:      20240505

#   package options
%option       with_xz   yes
%option       with_xar  yes

#   list of sources
Source0:      http://www.libarchive.org/downloads/libarchive-%{version}.tar.gz
Patch0:       libarchive.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  zlib, bzip2
PreReq:       zlib, bzip2
%if "%{with_xz}" == "yes"
BuildPreReq:  xz
PreReq:       xz
%endif
%if "%{with_xar}" == "yes"
BuildPreReq:  libxml, openssl
PreReq:       libxml, openssl
%endif

%description
    Libarchive is a programming library that can create and read several
    different streaming archive formats, including most popular TAR
    variants and several CPIO formats. It can also write SHAR archives.
    The package contains a tar(1) compatible frontend, too.

%track
    prog libarchive = {
        version   = %{version}
        url       = http://www.libarchive.org/downloads/
        regex     = libarchive-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --enable-bsdtar \
        --enable-bsdcpio \
        --with-zlib \
        --with-bz2lib \
        --without-lz4 \
        --without-lzo2 \
%if "%{with_xz}" == "yes"
        --with-lzma \
%else
        --without-lzma \
%endif
%if "%{with_xar}" == "yes"
        --with-openssl \
        --with-xml2 \
%else
        --without-openssl \
        --without-xml2 \
%endif
        --without-nettle \
        --without-expat \
        --without-iconv \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

